package com.supervision.common.utils;

import com.supervision.common.constant.Constants;
import com.supervision.police.domain.ModelCase;
import lombok.extern.slf4j.Slf4j;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import java.io.IOException;
import java.io.InputStream;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.List;

@Slf4j
public class ExcelReader {

    /**
     * Excel读取 操作 xls文件
     */
    public static List<List<String>> readExcelLow2007(InputStream is, String sheetName) throws IOException {
        HSSFWorkbook wb = null;
        try {
            wb = new HSSFWorkbook(is);
        } catch (IOException e) {
            e.printStackTrace();
        }
        Sheet sheet;
        if (StringUtils.isEmpty(sheetName)) {
            sheet = wb.getSheetAt(0);
        } else {
            // 得到第一个sheet
            sheet = wb.getSheet(sheetName);
        }
        // 得到Excel的行数
        int totalRows = sheet.getPhysicalNumberOfRows();

        // 得到Excel的列数
        int totalCells = 0;
        if (totalRows >= 1 && sheet.getRow(0) != null) {
            totalCells = sheet.getRow(0).getPhysicalNumberOfCells();
        }

        List<List<String>> dataLst = new ArrayList<>();
        // 循环Excel的行
        for (int r = 0; r < totalRows; r++) {
            Row row = sheet.getRow(r);
            if (row == null) {
                continue;
            }
            List<String> rowLst = new ArrayList<>();
            // 循环Excel的列
            for (int c = 0; c < totalCells; c++) {
                Cell cell = row.getCell(c);
                String cellValue = "";
                if (null != cell) {
                    // 以下是判断数据的类
                    switch (cell.getCellType()) {
                        case NUMERIC: // 数字
                            cell.setCellType(CellType.STRING);
                            cellValue = String.valueOf(cell.getRichStringCellValue().getString());
                            break;
                        case STRING: // 字符串
                            cellValue = String.valueOf(cell.getStringCellValue());
                            break;
                        case BOOLEAN: // Boolean
                            cellValue = String.valueOf(cell.getBooleanCellValue());
                            break;
                        case FORMULA: // 公式
                            //判断嵌入单元格的图片
                            if (cell.getStringCellValue().contains("=DISPIMG(")) {
                                cellValue = "";
                            } else {
                                cellValue = String.valueOf(cell.getNumericCellValue());
                            }
                            break;
                        case BLANK: // 空值
                            cellValue = null;
                            break;
                        case ERROR: // 故障
                            cellValue = "非法字符";
                            break;
                        default:
                            cellValue = "未知类型";
                            break;
                    }
                }
                rowLst.add(cellValue);
            }
            //如果出现空行，则结束
            boolean isNull = false;
            for (String str : rowLst) {
                if (StringUtils.isNotEmpty(str)) {
                    isNull = false;
                    break;
                }
                isNull = true;
            }
            if (isNull) {
                return dataLst;
            }
            // 保存第r行的第c列
            dataLst.add(rowLst);
        }
        return dataLst;
    }

    /**
     * Excel读取 操作 2007+版本 xlsx文件
     */
    public static List<List<String>> readExcel2007(InputStream is, String sheetName) throws IOException {
        XSSFWorkbook wb = null;
        try {
            wb = new XSSFWorkbook(is);
        } catch (IOException e) {
            e.printStackTrace();
        }
        Sheet sheet;
        if (StringUtils.isEmpty(sheetName)) {
            sheet = wb.getSheetAt(0);
        } else {
            // 得到第一个sheet
            sheet = wb.getSheet(sheetName);
        }
        // 得到Excel的行数
        int totalRows = sheet.getPhysicalNumberOfRows();

        // 得到Excel的列数
        int totalCells = 0;
        if (totalRows >= 1 && sheet.getRow(0) != null) {
            totalCells = sheet.getRow(0).getPhysicalNumberOfCells();
        }

        List<List<String>> dataLst = new ArrayList<>();
        // 循环Excel的行
        for (int r = 0; r < totalRows; r++) {
            Row row = sheet.getRow(r);
            if (row == null) {
                continue;
            }
            List<String> rowLst = new ArrayList<>();
            // 循环Excel的列
            for (int c = 0; c < totalCells; c++) {
                Cell cell = row.getCell(c);
                String cellValue = "";
                if (null != cell) {
                    // 以下是判断数据的类
                    switch (cell.getCellType()) {
                        case NUMERIC: // 数字
//                            cell.setCellType(Cell.CELL_TYPE_STRING);
                            cell.setCellType(CellType.STRING);
                            cellValue = String.valueOf(cell.getRichStringCellValue().getString());
                            break;
                        case STRING: // 字符串
                            cellValue = String.valueOf(cell.getStringCellValue());
                            break;
                        case BOOLEAN: // Boolean
                            cellValue = String.valueOf(cell.getBooleanCellValue());
                            break;
                        case FORMULA: // 公式
                            if (cell.getCellFormula().contains("=DISPIMG(")) {
                                cellValue = "";
                            } else {
                                cellValue = cell.getCellFormula();
                            }
                            break;
                        case BLANK: // 空值
                            cellValue = null;
                            break;
                        case ERROR: // 故障
                            cellValue = "非法字符";
                            break;
                        default:
                            cellValue = "未知类型";
                            break;
                    }
                }
                rowLst.add(cellValue);
            }
            //如果出现空行，则结束
            boolean isNull = false;
            for (String str : rowLst) {
                if (StringUtils.isNotEmpty(str)) {
                    isNull = false;
                    break;
                }
                isNull = true;
            }
            if (isNull) {
                return dataLst;
            }
            // 保存第r行的第c列
            dataLst.add(rowLst);
        }
        return dataLst;
    }

    /**
     * 根据excel生成 实体类
     *
     * @param is
     * @return
     * @throws IOException
     */
    public static List<ModelCase> getCaseList(InputStream is, String fileSuffix, String sheetName) throws IOException {
        List<List<String>> list = new ArrayList<>();

        if ("xls".equals(fileSuffix)) {
            list = ExcelReader.readExcelLow2007(is, sheetName);
        } else if ("xlsx".equals(fileSuffix)) {
            list = ExcelReader.readExcel2007(is, sheetName);
        }

        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

        //遍历数据到实体集合开始
        List<ModelCase> listBean = new ArrayList<>();
        for (int i = 1; i < list.size(); i++) { // i=1是因为第一行不要
            ModelCase uBean = new ModelCase();
            List<String> listStr = list.get(i);
            for (int j = 0; j < listStr.size(); j++) {
                //.replace((char)12288, ' ') 替换中文全角空格(全角空格无法用trim去掉)为半角空格
                String str = listStr.get(j) == null ? null : listStr.get(j).replace((char)12288, ' ').trim();
                switch (j) {
                    case 0:
                        //案件编号
                        uBean.setCaseNo(str);
                        break;
                    case 1:
                        //案件名称
                        uBean.setCaseName(str);
                        break;
                    case 2:
                        //案件类型
                        uBean.setCaseTypeName(str);
                        break;
                    case 3:
                        //案件状态
                        uBean.setCaseStatusName(str);
                        break;
                    case 4:
                        //作案方式
                        uBean.setCrimeModeName(str);
                        break;
                    case 5:
                        //案件描述
                        uBean.setCaseDetail(str);
                        break;
                    case 6:
                        try {
                            //立案时间
                            uBean.setRegisterTime(format.parse(str));
                        } catch (Exception e) {
                            uBean.setRegisterTime(null);
                        }
                        break;
                    case 7:
                        try {
                            //受理时间
                            uBean.setAcceptTime(format.parse(str));
                        } catch (Exception e) {
                            uBean.setAcceptTime(null);
                        }
                        break;
                    default:
                }
            }
            listBean.add(uBean);
        } //遍历数据到实体集合结束
        return listBean;
    }

}