package com.supervision.common.utils;

import java.util.ArrayList;
import java.util.List;

/**
 * @author qmy
 * @description
 * @createTime 2022/4/22
 */
public class ListUtils {

    /**
     * list分页器
     * 注意：分页时一定要将list按统一顺序排序。
     * @param pageSize
     * @param pageIndex
     * @param list
     * @param <T>
     * @return
     */
    public static<T> List<T>  Pager(int pageSize, int pageIndex, List<T> list){
        //使用list 中的sublist方法分页
        List<T> dataList = new ArrayList<>();
        // 每页显示多少条记录

        int currentPage; //当前第几页数据
        // 一共多少条记录
        int totalRecord = list.size();
        // 一共多少页
        int totalPage = totalRecord % pageSize;
        if (totalPage > 0) {
            totalPage = totalRecord / pageSize + 1;
        } else {
            totalPage = totalRecord / pageSize;
        }

        System.out.println("总页数:" + totalPage);

        // 当前第几页数据
        currentPage = totalPage < pageIndex ? totalPage : pageIndex;

        // 起始索引
        int fromIndex = pageSize * (currentPage - 1);
        fromIndex = fromIndex > 0 ? fromIndex : 0;

        // 结束索引
        int toIndex = pageSize * currentPage > totalRecord ? totalRecord : pageSize * currentPage;
        try{
            dataList = list.subList(fromIndex, toIndex);
        }catch(IndexOutOfBoundsException e){
            e.printStackTrace();
        }
        return dataList;
    }

    /**
     * @description 获取当前页数
     * @method getCurrentPage
     * @param pageSize
     * @param pageIndex
     * @param list
     * @return int
     */
    public static<T> int  getCurrentPage(int pageSize, int pageIndex, List<T> list){
        //使用list 中的sublist方法分页
        List<T> dataList = new ArrayList<>();
        // 每页显示多少条记录

        int currentPage; //当前第几页数据
        // 一共多少条记录
        int totalRecord = list.size();
        // 一共多少页
        int totalPage = totalRecord % pageSize;
        if (totalPage > 0) {
            totalPage = totalRecord / pageSize + 1;
        } else {
            totalPage = totalRecord / pageSize;
        }

        System.out.println("总页数:" + totalPage);

        // 当前第几页数据
        currentPage = totalPage < pageIndex ? totalPage : pageIndex;

        return currentPage;
    }
}
