package com.supervision.police.controller;

import com.supervision.common.domain.R;
import com.supervision.police.domain.CasePerson;
import com.supervision.police.domain.ModelCase;
import com.supervision.police.service.ModelCaseService;
import io.swagger.annotations.ApiOperation;
import io.swagger.v3.oas.annotations.Operation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

@RestController
@Slf4j
@RequestMapping("modelCase")
public class ModelCaseController {

    @Autowired
    private ModelCaseService modelCaseService;

    /**
     * 查询列表
     * @param modelCase
     * @param page
     * @param size
     * @return
     */
    @PostMapping("/queryList")
    public R<?> queryList(@RequestBody ModelCase modelCase,
                          @RequestParam(required = false, defaultValue = "1") Integer page,
                          @RequestParam(required = false, defaultValue = "20") Integer size) {
        return modelCaseService.queryList(modelCase, page, size);
    }

    /**
     * 检查案件编号是否已存在
     * @param caseNo
     * @return
     */
    @GetMapping("/checkCaseNo")
    public R<?> checkCaseNo(@RequestParam String caseNo) {
        return modelCaseService.checkCaseNo(caseNo);
    }

    /**
     * 新增或修改
     * @param modelCase
     * @return
     */
    @PostMapping("/addOrUpd")
    public R<?> addOrUpd(@RequestBody ModelCase modelCase) {
        return modelCaseService.addOrUpd(modelCase);
    }

    /**
     * 删除
     * @param id
     * @return
     */
    @PostMapping("/del")
    public R<?> del(@RequestParam String id) {
        return modelCaseService.del(id);
    }

    /**
     * 查询案件任务
     * @param name
     * @return
     */
    @GetMapping("/getPerson")
    @Operation(summary = "getPersion")
    public R<?> getPerson(@RequestParam String caseId,
                          @RequestParam(required = false, defaultValue = "") String name) {
        return modelCaseService.getPerson(caseId, name);
    }

    @PostMapping("/addPerson")
    public R<?> addPerson(@RequestBody CasePerson person) {
        return modelCaseService.addPersion(person);
    }

    /**
     * 导入案件信息
     * @param file
     * @return
     */
    @PostMapping("/uploadCase")
    public R<?> uploadCase(@RequestPart MultipartFile file) {
        return modelCaseService.uploadCase(file);
    }

    /**
     * 获取指标结果
     * @param caseId
     * @param indexType
     * @return
     */
    @PostMapping("/getIndexDetail")
    public R<?> getIndexDetail(@RequestParam String caseId,
                               @RequestParam String indexType,
                               @RequestParam(required = false, defaultValue = "1") Integer page,
                               @RequestParam(required = false, defaultValue = "20") Integer size) {
        return modelCaseService.getIndexDetail(caseId, indexType, page, size);
    }

}
