package com.supervision.police.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.supervision.common.domain.R;
import com.supervision.police.domain.ModelAtomicIndex;
import com.supervision.police.domain.ModelIndex;
import com.supervision.police.service.ModelIndexService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 指标表(ModelIndex)表控制层
 *
 * @author qmy
 * @since 2024-07-05 09:20:10
 */
@RestController
@RequestMapping("modelIndex")
public class ModelIndexController {

    @Autowired
    private ModelIndexService modelIndexService;

    /**
     * 分页查询所有数据
     *
     * @param page 分页对象
     * @param modelIndex 查询实体
     * @return 所有数据
     */
    @PostMapping("/selectAll")
    public R<?> selectAll(@RequestBody ModelIndex modelIndex,
                          @RequestParam(required = false, defaultValue = "1") Integer page,
                          @RequestParam(required = false, defaultValue = "20") Integer size) {
        return modelIndexService.selectAll(modelIndex, page, size);
    }

    /**
     * 新增/修改数据
     *
     * @param modelIndex 实体对象
     * @return 新增结果
     */
    @PostMapping("/addOrUpd")
    public R<?> addOrUpd(@RequestBody ModelIndex modelIndex) {
        return modelIndexService.addOrUpd(modelIndex);
    }

    /**
     * 删除数据
     *
     * @param id 主键
     * @return 删除结果
     */
    @PostMapping("/del")
    public R<?> del(@RequestParam String id) {
        return modelIndexService.del(id);
    }

    /*****************************原子指标**************/

    /**
     * 分页查询所有数据
     *
     * @param page 分页对象
     * @param modelAtomicIndex 查询实体
     * @return 所有数据
     */
    @PostMapping("/selectAllAtomic")
    public R<?> selectAllAtomic(@RequestBody ModelAtomicIndex modelAtomicIndex,
                                @RequestParam(required = false, defaultValue = "1") Integer page,
                                @RequestParam(required = false, defaultValue = "20") Integer size) {
        return modelIndexService.selectAllAtomic(modelAtomicIndex, page, size);
    }

    /**
     * 新增/修改数据
     *
     * @param modelAtomicIndex 实体对象
     * @return 新增结果
     */
    @PostMapping("/addOrUpdAtomic")
    public R<?> addOrUpdAtomic(@RequestBody ModelAtomicIndex modelAtomicIndex) {
        return modelIndexService.addOrUpdAtomic(modelAtomicIndex);
    }

    /**
     * 删除数据
     *
     * @param id 主键
     * @return 删除结果
     */
    @PostMapping("/delAtomic")
    public R<?> delAtomic(@RequestParam String id) {
        return modelIndexService.delAtomic(id);
    }

}

